==> micro-website-base-core-1.2.1-sources.jar: com/ptteng/sca/micro/common/client/UserMessageSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.micro.common.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.micro.common.model.UserMessage;
import com.ptteng.micro.common.service.UserMessageService;

import java.util.List;
import java.util.Map;

public class UserMessageSCAClient implements UserMessageService {

    private UserMessageService userMessageService;

	public UserMessageService getUserMessageService() {
		return userMessageService;
	}
	
	
	public void setUserMessageService(UserMessageService userMessageService) {
		this.userMessageService =userMessageService;
	}
	
	
			   
		@Override
		public Long insert(UserMessage userMessage)throws ServiceException, ServiceDaoException{
		
		return userMessageService.insert(userMessage);
		          
		
		}	
		  
    	   
		@Override
		public List<UserMessage> insertList(List<UserMessage> userMessageList)throws ServiceException, ServiceDaoException{
		
		return userMessageService.insertList(userMessageList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return userMessageService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(UserMessage userMessage)throws ServiceException, ServiceDaoException{
		
		return userMessageService.update(userMessage);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<UserMessage> userMessageList)throws ServiceException, ServiceDaoException{
		
		return userMessageService.updateList(userMessageList);
		          
		
		}	
		  
    	   
		@Override
		public UserMessage getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return userMessageService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<UserMessage> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return userMessageService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserMessageIdsByUid(Long uid,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userMessageService.getUserMessageIdsByUid(uid,start,limit);
	
	
	}

	@Override
	public List<Long> getUserMessageIdsByUidAndType(Long uid, Integer type, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return userMessageService.getUserMessageIdsByUidAndType(uid, type, start, limit);
	}


	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserMessageIdsByUidAndStatus(Long uid,Integer status,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userMessageService.getUserMessageIdsByUidAndStatus(uid,status,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserMessageIdsByUid(Long uid)throws ServiceException, ServiceDaoException{
		
		return userMessageService.countUserMessageIdsByUid(uid);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserMessageIdsByUidAndStatus(Long uid,Integer status)throws ServiceException, ServiceDaoException{
		
		return userMessageService.countUserMessageIdsByUidAndStatus(uid,status);
	
	
	}
	
		
	
		@Override
	public List<Long> getUserMessageIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userMessageService.getUserMessageIds(start, limit);
	}

	@Override
	public Integer countUserMessageIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userMessageService.countUserMessageIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userMessageService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userMessageService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   userMessageService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.userMessageService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}


 
}

==> micro-website-base-core-2.1.5-sources.jar: com/ptteng/sca/micro/common/client/UserMessageSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.micro.common.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.micro.common.model.UserMessage;
import com.ptteng.micro.common.service.UserMessageService;

import java.util.List;
import java.util.Map;

public class UserMessageSCAClient implements UserMessageService {

    private UserMessageService userMessageService;

	public UserMessageService getUserMessageService() {
		return userMessageService;
	}
	
	
	public void setUserMessageService(UserMessageService userMessageService) {
		this.userMessageService =userMessageService;
	}
	
	
			   
		@Override
		public Long insert(UserMessage userMessage)throws ServiceException, ServiceDaoException{
		
		return userMessageService.insert(userMessage);
		          
		
		}	
		  
    	   
		@Override
		public List<UserMessage> insertList(List<UserMessage> userMessageList)throws ServiceException, ServiceDaoException{
		
		return userMessageService.insertList(userMessageList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return userMessageService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(UserMessage userMessage)throws ServiceException, ServiceDaoException{
		
		return userMessageService.update(userMessage);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<UserMessage> userMessageList)throws ServiceException, ServiceDaoException{
		
		return userMessageService.updateList(userMessageList);
		          
		
		}	
		  
    	   
		@Override
		public UserMessage getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return userMessageService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<UserMessage> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return userMessageService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserMessageIdsByUid(Long uid,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userMessageService.getUserMessageIdsByUid(uid,start,limit);
	
	
	}

	@Override
	public List<Long> getUserMessageIdsByUidAndType(Long uid, Integer type, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return userMessageService.getUserMessageIdsByUidAndType(uid, type, start, limit);
	}


	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserMessageIdsByUidAndStatus(Long uid,Integer status,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userMessageService.getUserMessageIdsByUidAndStatus(uid,status,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserMessageIdsByUid(Long uid)throws ServiceException, ServiceDaoException{
		
		return userMessageService.countUserMessageIdsByUid(uid);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserMessageIdsByUidAndStatus(Long uid,Integer status)throws ServiceException, ServiceDaoException{
		
		return userMessageService.countUserMessageIdsByUidAndStatus(uid,status);
	
	
	}
	
		
	
		@Override
	public List<Long> getUserMessageIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userMessageService.getUserMessageIds(start, limit);
	}

	@Override
	public Integer countUserMessageIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userMessageService.countUserMessageIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userMessageService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userMessageService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   userMessageService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.userMessageService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}

	@Override
	public Object getMapListByDynamicCondition(Class aClass, Map<String, Object> map, Integer integer, Integer integer1) throws ServiceException, ServiceDaoException {
		return null;
	}


}
